@@ -17,13 +17,19 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with Acanban.  If not, see <https://www.gnu.org/licenses/>.
 
-from appdirs import site_config_dir, user_config_dir
+from hypercorn.middleware import HTTPToHTTPSRedirectMiddleware
 from hypercorn.trio import serve
+from hypercorn.typing import ASGIFramework
 from trio import run
 
-from . import app
-from .config import hypercorn_config
+from . import app as acanban
+from .config import acanban_config, hypercorn_config, rethinkdb_config
 
 if __name__ == '__main__':
-    config = hypercorn_config(user_config_dir(), site_config_dir())
-    run(serve, app, config)
+    domain = acanban_config().get('domain')
+    acanban.rethinkdb_config = rethinkdb_config()
+    if domain is None:
+        app: ASGIFramework = acanban
+    else:
+        app = HTTPToHTTPSRedirectMiddleware(acanban, domain)
+    run(serve, app, hypercorn_config())
